from raptus.multilanguagepfg import extender
from raptus.multilanguagepfg import config

from Products.CMFCore.utils import getToolByName

extenders = [extender.FormFolderExtender,
             extender.BaseFormFieldExtender,
             extender.ThanksPageExtender,
             extender.FGLikertFieldExtender,
             extender.FieldsetFolderExtender]

indexes = ('SearchableText', 'Subject', 'Title', 'Description', 'sortable_title',)

def reindex(portal):
    catalog = getToolByName(portal, 'portal_catalog')
    for index in indexes:
        catalog.reindexIndex(index, portal.REQUEST)

def install(context):

    if context.readDataFile('raptus.multilanguagepfg_install.txt') is None:
        return
    
    portal = context.getSite()
    quickinstaller = getToolByName(portal, 'portal_quickinstaller')

    sm = portal.getSiteManager()
    for extender in extenders:
        sm.registerAdapter(extender, name=config.PROJECT_NAME + extender.__name__)
        
    reindex(portal)
    
def uninstall(context):
    if context.readDataFile('raptus.multilanguagepfg_install.txt') is None and \
       context.readDataFile('raptus.multilanguagepfg_uninstall.txt') is None:
        return
    
    portal = context.getSite()
    sm = portal.getSiteManager()
    for extender in extenders:
        sm.unregisterAdapter(extender, name=config.PROJECT_NAME + extender.__name__)
        
    reindex(portal)
    


from raptus.multilanguagepfg.extender.form import FormFolderExtender

from raptus.multilanguagepfg.extender.fieldsBase import BaseFormFieldExtender

from raptus.multilanguagepfg.extender.thanksPage import ThanksPageExtender

from raptus.multilanguagepfg.extender.formLikertField import FGLikertFieldExtender

from raptus.multilanguagepfg.extender.fieldset import FieldsetFolderExtender


from zope.component import adapts

from archetypes.schemaextender.interfaces import ISchemaExtender

from raptus.multilanguagefields import widgets
from raptus.multilanguageplone.extender import fields
from raptus.multilanguageplone.extender.folder import FolderExtender

from Products.ATContentTypes.configuration import zconf
from Products.Archetypes.atapi import AnnotationStorage

from Products.PloneFormGen.content.form import FormFolder
from Products.PloneFormGen import PloneFormGenMessageFactory as _


class FormFolderExtender(FolderExtender):

    adapts(FormFolder)
    
    fields = FolderExtender.fields + [
        fields.StringField('submitLabel',
            storage=AnnotationStorage(migrate=True),
            required=0,
            searchable=0,
            default=_("Submit"),
            widget=widgets.StringWidget(
                label=_(u'label_submitlabel_text', default=u"Submit Button Label"),
                description = _(u'help_submitlabel_text', default=u""),
            ),
        ),
        fields.StringField('resetLabel',
            storage=AnnotationStorage(migrate=True),
            required=0,
            searchable=0,
            default=_("Reset"),
            widget=widgets.StringWidget(
                    label=_(u'label_reset_button', default=u"Reset Button Label"),
            ),
        ),
        fields.TextField('formPrologue',
            storage=AnnotationStorage(migrate=True),
            schemata='default',
            required=False,
            # Disable search to bypass a unicode decode error
            # in portal_catalog indexes.
            searchable=False,
            primary=False,
            validators = ('isTidyHtmlWithCleanup', ),
            default_content_type = zconf.ATDocument.default_content_type,
            default_output_type = 'text/x-html-safe',
            allowable_content_types = zconf.ATDocument.allowed_content_types,
            widget = widgets.RichWidget(
                label = _(u'label_prologue_text', default=u"Form Prologue"),
                description = _(u'help_prologue_text',
                    default=u"This text will be displayed above the form fields."),
                rows = 8,
                allow_file_upload = zconf.ATDocument.allow_document_upload,
            ),
        ),
        fields.TextField('formEpilogue',
            storage=AnnotationStorage(migrate=True),
            schemata='default',
            required=False,
            # Disable search to bypass a unicode decode error
            # in portal_catalog indexes.
            searchable=False,
            primary=False,
            validators = ('isTidyHtmlWithCleanup', ),
            default_content_type = zconf.ATDocument.default_content_type,
            default_output_type = 'text/x-html-safe',
            allowable_content_types = zconf.ATDocument.allowed_content_types,
            widget = widgets.RichWidget(
                label = _(u'label_epilogue_text', default=u"Form Epilogue"),
                description = _(u'help_epilogue_text',
                    default=u"The text will be displayed after the form fields."),
                rows = 8,
                allow_file_upload = zconf.ATDocument.allow_document_upload,
            ),
        ),
    ]
    




    
